==> ToolChain_STM32_1.0.49.tar.bz: ToolChain_STM32_1.0.49/ToolChain/install_15_RADIO_CC1120.sh <==
#!/bin/bash
#
#
#  Install script for cc1120 radio support 
#
#  Initial Script written by Gregor Rebel 2010-2012.
# 
#  Published under GNU Lesser General Public License
#  Check LEGAL.txt for details.
#
# Tested successfully on:
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="400_radio_cc1120_spi"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="$INSTALLPATH"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1
#X COMPILE_OPTS += -DRADIO_CC1120_SPI=1

# external radio connected via SPI
MAIN_OBJS += radio_cc1120.o radio_cc1120_spi.o

# define size of header, footer and payload required for each network packet (required by ttc_radio_types.h)

RADIO_CC1120_HEADER_SIZE  = 1
RADIO_CC1120_FOOTER_SIZE  = 0
RADIO_CC1120_PAYLOAD_SIZE = 60

COMPILE_OPTS += -DRADIO_CC1120_HEADER_SIZE=\$(RADIO_CC1120_HEADER_SIZE)
COMPILE_OPTS += -DRADIO_CC1120_FOOTER_SIZE=\$(RADIO_CC1120_FOOTER_SIZE)
COMPILE_OPTS += -DRADIO_CC1120_PAYLOAD_SIZE=\$(RADIO_CC1120_PAYLOAD_SIZE)

#{ ensure that header size is large egnough to store cc1120 headers
ifndef TTC_NETWORK_MAX_HEADER_SIZE
  TTC_NETWORK_MAX_HEADER_SIZE=\$(RADIO_CC1120_HEADER_SIZE)
endif
INCREASE_SIZE := \$(shell echo \${TTC_NETWORK_MAX_HEADER_SIZE}\<\${TTC_NETWORK_MAX_HEADER_SIZE} | bc)
ifeq "\$(INCREASE_SIZE)" "1"
  undef TTC_NETWORK_MAX_HEADER_SIZE
  TTC_NETWORK_MAX_HEADER_SIZE=\$(RADIO_CC1120_HEADER_SIZE)
endif
#}
#{ ensure that footer size is large egnough to store cc1120 footers
ifndef TTC_NETWORK_MAX_FOOTER_SIZE
  TTC_NETWORK_MAX_FOOTER_SIZE=\$(RADIO_CC1120_FOOTER_SIZE)
endif
INCREASE_SIZE := \$(shell echo \${TTC_NETWORK_MAX_FOOTER_SIZE}\<\${RADIO_CC1120_FOOTER_SIZE} | bc)
ifeq "\$(INCREASE_SIZE)" "1"
  undef TTC_NETWORK_MAX_FOOTER_SIZE
  TTC_NETWORK_MAX_FOOTER_SIZE=\$(RADIO_CC1120_FOOTER_SIZE)
endif
#}
#{ ensure that payload size is large egnough to store cc1120 payloads
ifndef TTC_NETWORK_MAX_PAYLOAD_SIZE
  TTC_NETWORK_MAX_PAYLOAD_SIZE=\$(RADIO_CC1120_PAYLOAD_SIZE)
endif
INCREASE_SIZE := \$(shell echo \${TTC_NETWORK_MAX_PAYLOAD_SIZE}\<\${RADIO_CC1120_PAYLOAD_SIZE} | bc)
ifeq "\$(INCREASE_SIZE)" "1"
  undef TTC_NETWORK_MAX_PAYLOAD_SIZE
  TTC_NETWORK_MAX_PAYLOAD_SIZE=\$(RADIO_CC1120_PAYLOAD_SIZE)
endif
#}

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{ create activate script
  createActivateScriptHead $File "$0" "Architecture independent support for Universal Synchronous Asynchronous Serial Receiver Transmitter (RADIO)"
  cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_Additionals/${Name}_*

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}
  echo "Installed successfully: $Name"

  for Index in 1 2 3 4 5; do    
    Name="150_board_extension_radio_${Index}_cc1120"
    createExtensionMakefileHead ${Name}      #{ create makefile
    cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1

#{ TTC_RADIO${Index} pin configuration for  external radio transceiver #_${Index} cc1120 connected via SPI bus

# set type of driver to use (one from ttc_radio_types.h/ttc_radio_driver_e)
COMPILE_OPTS += -DTTC_RADIO${Index}=trd_cc1120_spi

# define spi interface to use (only required if connected via SPI)
COMPILE_OPTS += -DTTC_RADIO${Index}_SPI_INDEX=1

# define usart interface to use (only required if connected via USART)
#COMPILE_OPTS += -DTTC_RADIO${Index}_USART=TTC_USART1

# define pin configuration of GPIOs used for first radio
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_SPI_NSS=PIN_PC9
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_GDO0=PIN_PC13
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_GDO1=PIN_PC11
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_GDO2=PIN_PC8
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_GDO3=PIN_PB8
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_RESET=PIN_PB9

#}TTC_RADIO${Index}

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{ create activate script
    createActivateScriptHead $File "$0" "Example extension for external radio transceiver cc1120 connected via SPI bus"
    cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*

activate.400_radio_cc1120_spi.sh QUIET \"\$0\"
activate.500_ttc_usart.sh        QUIET \"\$0\"
activate.500_ttc_radio.sh        QUIET \"\$0\"
activate.500_ttc_gpio.sh         QUIET \"\$0\"
activate.500_ttc_spi.sh          QUIET \"\$0\"

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}
    echo "Installed successfully: $Name"
  done

    Name="150_board_extension_cc1120_uext"
    createExtensionMakefileHead ${Name}      #{ create makefile
    cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1

#{ TTC_RADIO1 pin configuration for  external radio transceiver #1 cc1120 connected via SPI bus

# set type of driver to use (one from ttc_radio_types.h/ttc_radio_driver_e)
COMPILE_OPTS += -DTTC_RADIO1=trd_cc1120_spi

# define spi interface to use (only required if connected via SPI)
COMPILE_OPTS += -DTTC_RADIO1_SPI_INDEX=1

# define pin configuration of GPIOs used for first radio
COMPILE_OPTS += -DTTC_RADIO1_PIN_SPI_NSS=PIN_PC9
COMPILE_OPTS += -DTTC_RADIO1_PIN_GDO0=PIN_PD8
COMPILE_OPTS += -DTTC_RADIO1_PIN_GDO1=PIN_PC11
COMPILE_OPTS += -DTTC_RADIO1_PIN_GDO2=PIN_PD9
COMPILE_OPTS += -DTTC_RADIO1_PIN_GDO3=PIN_PB8
COMPILE_OPTS += -DTTC_RADIO1_PIN_RESET=PIN_PB9

#}TTC_RADIO1


END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{ create activate script
    createActivateScriptHead $File "$0" "Example extension for external radio transceiver cc1120 connected via SPI bus"
    cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*

activate.400_radio_cc1120_spi.sh QUIET \"\$0\"
#activate.400_radio_cc1190.sh     QUIET \"\$0\"
#activate.500_ttc_usart.sh        QUIET \"\$0\"
activate.500_ttc_radio.sh        QUIET \"\$0\"
activate.500_ttc_gpio.sh         QUIET \"\$0\"
activate.500_ttc_spi.sh          QUIET \"\$0\"
activate.500_ttc_interrupt.sh    QUIET \"\$0\"

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}
    echo "Installed successfully: $Name"
  


cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.51.tar.bz: ToolChain_STM32_1.0.51/ToolChain/install_15_RADIO_CC1120.sh <==
#!/bin/bash
#
#
#  Install script for cc1120 radio support 
#
#  Initial Script written by Gregor Rebel 2010-2012.
# 
#  Published under GNU Lesser General Public License
#  Check LEGAL.txt for details.
#
# Tested successfully on:
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="400_radio_cc1120_spi"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="$INSTALLPATH"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1
#X COMPILE_OPTS += -DRADIO_CC1120_SPI=1

# external radio connected via SPI
MAIN_OBJS += radio_cc1120.o radio_cc1120_spi.o

# define size of header, footer and payload required for each network packet (required by ttc_radio_types.h)

RADIO_CC1120_HEADER_SIZE  = 1
RADIO_CC1120_FOOTER_SIZE  = 0
RADIO_CC1120_PAYLOAD_SIZE = 128

COMPILE_OPTS += -DRADIO_CC1120_HEADER_SIZE=\$(RADIO_CC1120_HEADER_SIZE)
COMPILE_OPTS += -DRADIO_CC1120_FOOTER_SIZE=\$(RADIO_CC1120_FOOTER_SIZE)
COMPILE_OPTS += -DRADIO_CC1120_PAYLOAD_SIZE=\$(RADIO_CC1120_PAYLOAD_SIZE)

#{ ensure that header size is large egnough to store cc1120 headers
ifndef TTC_NETWORK_MAX_HEADER_SIZE
  TTC_NETWORK_MAX_HEADER_SIZE=\$(RADIO_CC1120_HEADER_SIZE)
endif
INCREASE_SIZE := \$(shell echo \${TTC_NETWORK_MAX_HEADER_SIZE}\<\${TTC_NETWORK_MAX_HEADER_SIZE} | bc)
ifeq "\$(INCREASE_SIZE)" "1"
  undef TTC_NETWORK_MAX_HEADER_SIZE
  TTC_NETWORK_MAX_HEADER_SIZE=\$(RADIO_CC1120_HEADER_SIZE)
endif
#}
#{ ensure that footer size is large egnough to store cc1120 footers
ifndef TTC_NETWORK_MAX_FOOTER_SIZE
  TTC_NETWORK_MAX_FOOTER_SIZE=\$(RADIO_CC1120_FOOTER_SIZE)
endif
INCREASE_SIZE := \$(shell echo \${TTC_NETWORK_MAX_FOOTER_SIZE}\<\${RADIO_CC1120_FOOTER_SIZE} | bc)
ifeq "\$(INCREASE_SIZE)" "1"
  undef TTC_NETWORK_MAX_FOOTER_SIZE
  TTC_NETWORK_MAX_FOOTER_SIZE=\$(RADIO_CC1120_FOOTER_SIZE)
endif
#}
#{ ensure that payload size is large egnough to store cc1120 payloads
ifndef TTC_NETWORK_MAX_PAYLOAD_SIZE
  TTC_NETWORK_MAX_PAYLOAD_SIZE=\$(RADIO_CC1120_PAYLOAD_SIZE)
endif
INCREASE_SIZE := \$(shell echo \${TTC_NETWORK_MAX_PAYLOAD_SIZE}\<\${RADIO_CC1120_PAYLOAD_SIZE} | bc)
ifeq "\$(INCREASE_SIZE)" "1"
  undef TTC_NETWORK_MAX_PAYLOAD_SIZE
  TTC_NETWORK_MAX_PAYLOAD_SIZE=\$(RADIO_CC1120_PAYLOAD_SIZE)
endif
#}

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{ create activate script
  createActivateScriptHead $File "$0" "Architecture independent support for Universal Synchronous Asynchronous Serial Receiver Transmitter (RADIO)"
  cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_Additionals/${Name}_*

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}
  echo "Installed successfully: $Name"

  for Index in 1 2 3 4 5; do    
    Name="150_board_extension_radio_${Index}_cc1120"
    createExtensionMakefileHead ${Name}      #{ create makefile
    cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1

#{ TTC_RADIO${Index} pin configuration for  external radio transceiver #_${Index} cc1120 connected via SPI bus

# set type of driver to use (one from ttc_radio_types.h/ttc_radio_driver_e)
COMPILE_OPTS += -DTTC_RADIO${Index}=trd_cc1120_spi

# define spi interface to use (only required if connected via SPI)
COMPILE_OPTS += -DTTC_RADIO${Index}_SPI_INDEX=1

# define usart interface to use (only required if connected via USART)
#COMPILE_OPTS += -DTTC_RADIO${Index}_USART=TTC_USART1

# define pin configuration of GPIOs used for first radio
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_SPI_NSS=PIN_PC9
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_GDO0=PIN_PC13
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_GDO1=PIN_PC11
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_GDO2=PIN_PC8
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_GDO3=PIN_PB8
COMPILE_OPTS += -DTTC_RADIO${Index}_PIN_RESET=PIN_PB9

#}TTC_RADIO${Index}

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{ create activate script
    createActivateScriptHead $File "$0" "Example extension for external radio transceiver cc1120 connected via SPI bus"
    cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*

activate.400_radio_cc1120_spi.sh QUIET \"\$0\"
activate.500_ttc_usart.sh        QUIET \"\$0\"
activate.500_ttc_radio.sh        QUIET \"\$0\"
activate.500_ttc_gpio.sh         QUIET \"\$0\"
activate.500_ttc_spi.sh          QUIET \"\$0\"

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}
    echo "Installed successfully: $Name"
  done

    Name="150_board_extension_cc1120_uext"
    createExtensionMakefileHead ${Name}      #{ create makefile
    cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1

#{ TTC_RADIO1 pin configuration for  external radio transceiver #1 cc1120 connected via SPI bus

# set type of driver to use (one from ttc_radio_types.h/ttc_radio_driver_e)
COMPILE_OPTS += -DTTC_RADIO1=trd_cc1120_spi

# define spi interface to use (only required if connected via SPI)
COMPILE_OPTS += -DTTC_RADIO1_SPI_INDEX=1

# define pin configuration of GPIOs used for first radio
COMPILE_OPTS += -DTTC_RADIO1_PIN_SPI_NSS=PIN_PB15
COMPILE_OPTS += -DTTC_RADIO1_PIN_GDO0=PIN_PD5
COMPILE_OPTS += -DTTC_RADIO1_PIN_GDO1=PIN_PC11
COMPILE_OPTS += -DTTC_RADIO1_PIN_GDO2=PIN_PD6
COMPILE_OPTS += -DTTC_RADIO1_PIN_GDO3=PIN_PB8
COMPILE_OPTS += -DTTC_RADIO1_PIN_RESET=PIN_PB9

#}TTC_RADIO1


END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{ create activate script
    createActivateScriptHead $File "$0" "Example extension for external radio transceiver cc1120 connected via SPI bus"
    cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*

activate.400_radio_cc1120_spi.sh QUIET \"\$0\"
#activate.400_radio_cc1190.sh     QUIET \"\$0\"
#activate.500_ttc_usart.sh        QUIET \"\$0\"
activate.500_ttc_radio.sh        QUIET \"\$0\"
activate.500_ttc_gpio.sh         QUIET \"\$0\"
activate.500_ttc_spi.sh          QUIET \"\$0\"
activate.500_ttc_interrupt.sh    QUIET \"\$0\"

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}
    echo "Installed successfully: $Name"
  


cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
